@@ -704,7 +704,10 @@ pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
+pref("network.IDN.whitelist.lu", true);
 pref("network.IDN.whitelist.no", true);
+pref("network.IDN.whitelist.nu", true);
+pref("network.IDN.whitelist.nz", true);
 pref("network.IDN.whitelist.pl", true);
 pref("network.IDN.whitelist.pr", true);
 pref("network.IDN.whitelist.se", true);
@@ -714,12 +717,23 @@ pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
-// non-ccTLDs
+// IDN ccTLDs
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
+// sa, Saudi Arabia, .<al-Saudiah>
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// jo, Jordan, .<Al-Ordon>
+pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+
+// gTLDs
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
 pref("network.IDN.whitelist.org", true);
+pref("network.IDN.whitelist.tel", true);
 
 // NOTE: Before these can be removed, one of bug 414812's tests must be updated
 //       or it will likely fail!  Please CC jwalden+bmo on the bug associated
@@ -799,7 +813,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 814 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 828 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -818,9 +832,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 834 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 848 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 841 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 855 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1182,15 +1196,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1581 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1595 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1998 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2012 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2199 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2213 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2293 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2307 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2296 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2310 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1458,15 +1472,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2566 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2580 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2634 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2648 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2660 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2674 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2680 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2694 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2688 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2702 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1490,7 +1504,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2717 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2731 "/home/karma/src/build/mozilla/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
